@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Engine/Danga/Socket.pm 2431 2007-09-03T13:55:47.913037Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Engine/Danga/Socket.pm 2473 2007-09-04T07:08:58.221716Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -61,8 +61,12 @@ sub send_request
     if ($req->requires_name_lookup) {
         $self->lookup_name($c, $req);
     } else {
-        $self->block_private_ip_address($c, $req, $req->uri->host)
-            or $self->start_request($c, $req);
+        $req->uri->host( $req->notes('resolved_ip') ) 
+            if $req->notes('resolved_ip');
+        if ($self->block_private_ip_address($c, $req, $req->uri->host)) {
+            return;
+        }
+        $self->start_request($c, $req);
     }
 }
 
